arfs package
============

Submodules
----------

arfs.allrelevant module
-----------------------

.. automodule:: arfs.allrelevant
   :members:
   :undoc-members:
   :show-inheritance:

arfs.featselect module
----------------------

.. automodule:: arfs.featselect
   :members:
   :undoc-members:
   :show-inheritance:

arfs.sampling module
--------------------

.. automodule:: arfs.sampling
   :members:
   :undoc-members:
   :show-inheritance:

arfs.utils module
-----------------

.. automodule:: arfs.utils
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: arfs
   :members:
   :undoc-members:
   :show-inheritance:
